@@ -93,8 +93,8 @@ void Export_pyste_src_Image()
         .def("colorize", (void (Magick::Image::*)(const unsigned int, const unsigned int, const unsigned int, const Magick::Color&) )&Magick::Image::colorize)
         .def("colorize", (void (Magick::Image::*)(const unsigned int, const Magick::Color&) )&Magick::Image::colorize)
         .def("comment", (void (Magick::Image::*)(const std::string&) )&Magick::Image::comment)
-        .def("compare", &Magick::Image::compare)
-        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const ssize_t, const ssize_t, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_3_4())
+        .def("compare", (bool (Magick::Image::*)(const Magick::Image&) )&Magick::Image::compare)
+        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const ::ssize_t, const ::ssize_t, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_3_4())
         .def("composite", (void (Magick::Image::*)(const Magick::Image&, const Magick::Geometry&, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
         .def("composite", (void (Magick::Image::*)(const Magick::Image&, const MagickCore::GravityType, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
         .def("contrast", &Magick::Image::contrast)
@@ -111,18 +111,18 @@ void Export_pyste_src_Image()
         .def("equalize", &Magick::Image::equalize)
         .def("erase", &Magick::Image::erase)
         .def("flip", &Magick::Image::flip)
-        .def("floodFillColor", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Color&) )&Magick::Image::floodFillColor)
+        .def("floodFillColor", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillColor", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&) )&Magick::Image::floodFillColor)
-        .def("floodFillColor", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
+        .def("floodFillColor", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillColor", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillOpacity", &Magick::Image::floodFillOpacity)
-        .def("floodFillTexture", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Image&) )&Magick::Image::floodFillTexture)
+        .def("floodFillTexture", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Image&) )&Magick::Image::floodFillTexture)
         .def("floodFillTexture", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Image&) )&Magick::Image::floodFillTexture)
-        .def("floodFillTexture", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Image&, const Magick::Color&) )&Magick::Image::floodFillTexture)
+        .def("floodFillTexture", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Image&, const Magick::Color&) )&Magick::Image::floodFillTexture)
         .def("floodFillTexture", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Image&, const Magick::Color&) )&Magick::Image::floodFillTexture)
         .def("flop", &Magick::Image::flop)
         .def("frame", (void (Magick::Image::*)(const Magick::Geometry&) )&Magick::Image::frame, Magick_Image_frame_overloads_0_1())
-        .def("frame", (void (Magick::Image::*)(const size_t, const size_t, const ssize_t, const ssize_t) )&Magick::Image::frame, Magick_Image_frame_overloads_2_4())
+        .def("frame", (void (Magick::Image::*)(const size_t, const size_t, const ::ssize_t, const ::ssize_t) )&Magick::Image::frame, Magick_Image_frame_overloads_2_4())
         .def("gamma", (void (Magick::Image::*)(const double) )&Magick::Image::gamma)
         .def("gamma", (void (Magick::Image::*)(const double, const double, const double) )&Magick::Image::gamma)
         .def("gaussianBlur", &Magick::Image::gaussianBlur)
@@ -169,6 +169,7 @@ void Export_pyste_src_Image()
         .def("spread", &Magick::Image::spread, Magick_Image_spread_overloads_0_1())
         .def("stegano", &Magick::Image::stegano)
         .def("stereo", &Magick::Image::stereo)
+        .def("strip", &Magick::Image::strip)
         .def("swirl", &Magick::Image::swirl)
         .def("texture", &Magick::Image::texture)
         .def("threshold", &Magick::Image::threshold)
@@ -183,7 +184,7 @@ void Export_pyste_src_Image()
         .def("write", (void (Magick::Image::*)(Magick::Blob*) )&Magick::Image::write)
         .def("write", (void (Magick::Image::*)(Magick::Blob*, const std::string&) )&Magick::Image::write)
         .def("write", (void (Magick::Image::*)(Magick::Blob*, const std::string&, const size_t) )&Magick::Image::write)
-        .def("write", (void (Magick::Image::*)(const ssize_t, const ssize_t, const size_t, const size_t, const std::string&, const MagickCore::StorageType, void*) )&Magick::Image::write)
+        .def("write", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const size_t, const size_t, const std::string&, const MagickCore::StorageType, void*) )&Magick::Image::write)
         .def("zoom", &Magick::Image::zoom)
         .def("adjoin", (void (Magick::Image::*)(const bool) )&Magick::Image::adjoin)
         .def("adjoin", (bool (Magick::Image::*)() const)&Magick::Image::adjoin)
@@ -299,8 +300,8 @@ void Export_pyste_src_Image()
         .def("penColor", (Magick::Color (Magick::Image::*)() const)&Magick::Image::penColor)
         .def("penTexture", (void (Magick::Image::*)(const Magick::Image&) )&Magick::Image::penTexture)
         .def("penTexture", (Magick::Image (Magick::Image::*)() const)&Magick::Image::penTexture)
-        .def("pixelColor", (void (Magick::Image::*)(const ssize_t, const ssize_t, const Magick::Color&) )&Magick::Image::pixelColor)
-        .def("pixelColor", (Magick::Color (Magick::Image::*)(const ssize_t, const ssize_t) const)&Magick::Image::pixelColor)
+        .def("pixelColor", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Color&) )&Magick::Image::pixelColor)
+        .def("pixelColor", (Magick::Color (Magick::Image::*)(const ::ssize_t, const ::ssize_t) const)&Magick::Image::pixelColor)
         .def("profile", (void (Magick::Image::*)(const std::string, const Magick::Blob&) )&Magick::Image::profile)
         .def("profile", (Magick::Blob (Magick::Image::*)(const std::string) const)&Magick::Image::profile)
         .def("quality", (void (Magick::Image::*)(const size_t) )&Magick::Image::quality)
